@@ -18,7 +18,7 @@ use Module::Load qw( load );
 use Scalar::Util qw(blessed openhandle);
 use Try::Tiny qw(try catch);
 
-our $VERSION = '6.76';
+our $VERSION = '6.80';
 
 sub new
 {
@@ -73,6 +73,8 @@ sub new
     my $no_proxy = exists $cnf{no_proxy} ? delete $cnf{no_proxy} : [];
     Carp::croak(qq{no_proxy must be an arrayref, not $no_proxy!}) if ref $no_proxy ne 'ARRAY';
 
+    my $proxy = exists $cnf{proxy} ? delete $cnf{proxy} : [];
+
     my $cookie_jar = delete $cnf{cookie_jar};
     my $conn_cache = delete $cnf{conn_cache};
     my $keep_alive = delete $cnf{keep_alive};
@@ -129,10 +131,10 @@ sub new
     $self->parse_head($parse_head);
     $self->env_proxy if $env_proxy;
 
-    if (exists $cnf{proxy}) {
+    if ($proxy) {
         Carp::croak(qq{proxy must be an arrayref, not $cnf{proxy}!})
-            if ref $cnf{proxy} ne 'ARRAY';
-        $self->proxy($cnf{proxy});
+            if ref $proxy ne 'ARRAY';
+        $self->proxy($proxy);
     }
 
     $self->protocols_allowed(  $protocols_allowed  ) if $protocols_allowed;
@@ -600,7 +602,7 @@ sub is_online {
 }
 
 
-my @ANI = qw(- \ | /);
+my @ANI = ('-', '\\', '|', '/');
 
 sub progress {
     my($self, $status, $m) = @_;
@@ -642,7 +644,7 @@ sub is_protocol_supported
 {
     my($self, $scheme) = @_;
     if (ref $scheme) {
-	# assume we got a reference to an URI object
+	# assume we got a reference to a URI object
 	$scheme = $scheme->scheme;
     }
     else {
@@ -1623,6 +1625,14 @@ This option is initialized from the C<PERL_LWP_SSL_VERIFY_HOSTNAME> environment
 variable.  If this environment variable isn't set; then C<verify_hostname>
 defaults to 1.
 
+Please note that recently the overall effect of this option with regards to
+SSL handling has changed. As of version 6.11 of L<LWP::Protocol::https>, which is an
+external module, SSL certificate verification was harmonized to behave in sync with
+L<IO::Socket::SSL>. With this change, setting this option no longer disables all SSL
+certificate verification, only the hostname checks. To disable all verification,
+use the C<SSL_verify_mode> option in the C<ssl_opts> attribute. For example:
+C<$ua->ssl_opts(SSL_verify_mode => IO::Socket::SSL::SSL_VERIFY_NONE);>
+
 =item C<SSL_ca_file> => $path
 
 The path to a file containing Certificate Authority certificates.
@@ -1663,6 +1673,9 @@ will have a standard HTTP Status Code (500).  This response will have the
 "Client-Warning" header set to the value of "Internal response".  See the
 L<LWP::UserAgent/get> method description below for further details.
 
+Disabling the timeout is not supported,
+but it can be set to an arbitrarily large value.
+
 =head1 PROXY ATTRIBUTES
 
 The following methods set up when requests should be passed via a
@@ -1675,8 +1688,8 @@ proxy server.
 Load proxy settings from C<*_proxy> environment variables.  You might
 specify proxies like this (sh-syntax):
 
-  gopher_proxy=http://proxy.my.place/
-  wais_proxy=http://proxy.my.place/
+  gopher_proxy=http://proxy.example.org/
+  wais_proxy=http://proxy.example.org/
   no_proxy="localhost,example.com"
   export gopher_proxy wais_proxy no_proxy
 
@@ -1987,6 +2000,8 @@ Uses L<File::Copy/move> to attempt to atomically replace the C<$filename>.
 
 The return value is an L<HTTP::Response> object.
 
+Dies if the response to fetch the document contains an C<X-Died> header.
+
 =head2 patch
 
     # Any version of HTTP::Message works with this form:
